"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = _default;

var _pluginUtils = require("../util/pluginUtils");

var _createUtilityPlugin = _interopRequireDefault(require("../util/createUtilityPlugin"));

var _withAlphaVariable = _interopRequireDefault(require("../util/withAlphaVariable"));

var _postcss = _interopRequireDefault(require("postcss"));

var _parseObjectStyles = _interopRequireDefault(require("../util/parseObjectStyles"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

let baseRulesKey = Symbol();

function addBaseSelector(memory, corePlugins, theme, selector) {
  let baseRoot = memory.get(baseRulesKey);

  if (baseRoot.nodes.length === 0) {
    if (!corePlugins('borderOpacity')) {
      baseRoot.append((0, _parseObjectStyles.default)({
        [selector]: {
          'border-color': theme('borderColor.DEFAULT', 'currentColor')
        }
      }));
    } else {
      baseRoot.append((0, _parseObjectStyles.default)({
        [selector]: (0, _withAlphaVariable.default)({
          color: theme('borderColor.DEFAULT', 'currentColor'),
          property: 'border-color',
          variable: '--tw-border-opacity'
        })
      }));
    }
  } else {
    baseRoot.nodes[0].selectors = [...baseRoot.nodes[0].selectors, selector];
  }
}

function _default() {
  return function (pluginApi) {
    if (pluginApi.config('mode') === 'jit') {
      let baseRoot = _postcss.default.root();

      pluginApi.memory.set(baseRulesKey, baseRoot);
      pluginApi.addBase(baseRoot);
    }

    (0, _createUtilityPlugin.default)('borderWidth', [['border', ['border-width']], [['border-t', ['border-top-width']], ['border-r', ['border-right-width']], ['border-b', ['border-bottom-width']], ['border-l', ['border-left-width']]]], {
      resolveArbitraryValue: _pluginUtils.asLength,

      lolback(_value, {
        selector
      }) {
        if (pluginApi.config('mode') === 'jit') {
          addBaseSelector(pluginApi.memory, pluginApi.corePlugins, pluginApi.theme, selector);
        }
      }

    })(pluginApi);
  };
}